<?php

if (!defined('ABSPATH')) exit;

class sst_admin {
    public $page_ids;
    public $admin_page_url = 'options-general.php';

    function __construct() {
        add_action('admin_enqueue_scripts', array(&$this, 'admin_enqueue_scripts'));

        add_action('admin_menu', array(&$this, 'admin_menu'));
        add_action('admin_init', array(&$this, 'save_settings'));

        add_action('wp_ajax_simple_smtp_testool', array(&$this, 'ajax_test'));

        add_filter('plugin_row_meta', array(&$this, 'plugin_row_meta'), 10, 2);
        add_filter('plugin_action_links_simple-smtp-tools/simple-smtp-tools.php', array(&$this, 'plugin_action_links'));
    }

    public function ajax_test() {
        check_ajax_referer('simple-smtp-testool-options');
        @set_time_limit(300);

        $timestamp = date('Y-m-d H:i:s');

        $message = __("This is the message sent from your website to test email server.", "simple-smtp-tools").SST_EOL;
        $message.= __("This message was sent at:", "simple-smtp-tools")." ".$timestamp.SST_EOL.SST_EOL;
        $message.= __("Your website is properly configured to send e-mails.", "simple-smtp-tools");

        wp_mail($_POST['test_email'], $_POST['test_subject'], $message);

        global $phpmailer;

        $props = array('CharSet', 'ContentType', 'Encoding', 'From', 'FromName', 'Sender', 'Mailer', 'Host', 'Port', 'SMTPSecure', 'SMTPAuth', 'Timeout');

        $test_settings = '<h3 class="sst-setup">'.__("Setup", "simple-smtp-tools").'</h3>';
        $test_settings.= __("PHPMailer Version", "simple-smtp-tools").': <strong>'.$phpmailer->Version.'</strong><br/>';

        foreach ($props as $property) {
            $test_settings.= $property.': <strong>'.$phpmailer->$property.'</strong><br/>';
        }

        $test_class = 'sst-green';
        $test_message = __("Everything looks OK, email is successfully sent.", "simple-smtp-tools");

        if ($phpmailer->ErrorInfo != '') {
            $test_class = 'sst-red';
            $test_message = __("An error occured", "simple-smtp-tools").':<br/><strong>'.$phpmailer->ErrorInfo.'</strong>';
        }

        die('<div class="'.$test_class.'"><h3>'.__("Results", "simple-smtp-tools").'</h3>'.$test_message.$test_settings.'</div>');
    }

    public function plugin_row_meta($links, $plugin_file) {
        if ($plugin_file == 'simple-smtp-tools/simple-smtp-tools.php') {
            $links[] = '<a href="http://www.millan.rs/" target="_blank">SMART Plugins</a>';
            $links[] = '<a href="http://codecanyon.net/user/GDragoN/portfolio?ref=GDragoN" target="_blank">On CodeCanyon</a>';
        }

        return $links;
    }

    public function plugin_action_links($links) {
        $links[] = '<a href="'.$this->admin_page_url.'?page=simple-smtp-tools">'.__("Settings", "simple-smtp-tools").'</a>';

	return $links;
    }

    public function admin_enqueue_scripts($hook) {
        if ($hook == 'settings_page_simple-smtp-tools' || $hook == 'smart-plugins_page_simple-smtp-tools') {
            wp_enqueue_script('jquery');
            wp_enqueue_script('jquery-form');

            wp_enqueue_script('sst-admin-js', (defined('SCRIPT_DEBUG') && SCRIPT_DEBUG ? SST_URL.'js/admin.js' : SST_URL.'js/admin.min.js'), array('jquery', 'jquery-form'), null, true);

            wp_enqueue_style('sst-admin-css', SST_URL.'css/admin.css');
        }
    }

    public function admin_menu() {
        if (defined('SMART_PLUGINS_CENTRAL')) {
            $this->page_ids[] = add_submenu_page('smart-plugins-central', __("Simple SMTP Tools", "simple-smtp-tools"), __("SMTP Tools", "simple-smtp-tools"), 'activate_plugins', 'simple-smtp-tools', array(&$this, 'settings'));
        } else {
            $this->page_ids[] = add_options_page(__("Simple SMTP Tools", "simple-smtp-tools"), __("Simple SMTP Tools", "simple-smtp-tools"), 'activate_plugins', 'simple-smtp-tools', array(&$this, 'settings'));
        }

        foreach ($this->page_ids as $id) {
            add_action('load-'.$id, array(&$this, 'load_admin_page'));
        }
    }

    public function load_admin_page() {
        $screen = get_current_screen();
        
        $screen->set_help_sidebar('
            <p><strong>SMART Plugins:</strong></p>
            <p><a target="_blank" href="http://www.smartplugins.info/">'.__("Website", "simple-smtp-tools").'</a></p>
            <p><a target="_blank" href="http://codecanyon.net/user/GDragoN/portfolio?ref=GDragoN">'.__("On CodeCanyon", "simple-smtp-tools").'</a></p>
            <p><a target="_blank" href="http://twitter.com/millanrs">'.__("On Twitter", "simple-smtp-tools").'</a></p>
            <p><a target="_blank" href="http://facebook.com/smartplugins">'.__("On Facebook", "simple-smtp-tools").'</a></p>');

        $screen->add_help_tab(array(
            'id' => 'scs-screenhelp-info',
            'title' => __("Information", "simple-smtp-tools"),
            'content' => '<p>'.__("Modify send email and from fields for emails and set external SMTP server (with direct support for GMail, Yahoo, Outlook...) to send emails in WordPress.", "simple-smtp-tools").'</p>
                <h5>'.__("Useful Links", "simple-smtp-tools").'</h5>
                <p><a target="_blank" href="http://www.smartplugins.info/plugin/wordpress/simple-smtp-tools/">'.__("Plugin Homepage", "simple-smtp-tools").'</a></p>
                <p><a target="_blank" href="http://d4p.me/ccsst">'.__("Plugin On CodeCanyon", "simple-smtp-tools").'</a></p>'
        ));

        $screen->add_help_tab(array(
            'id' => 'scs-screenhelp-support',
            'title' => __("Support", "simple-smtp-tools"),
            'content' => '<h5>'.__("Support Reources", "simple-smtp-tools").'</h5>
                <p><a target="_blank" href="http://forum.smartplugins.info/forums/forum/simple/simple-smtp-tools/">'.__("Official Support Forum", "simple-smtp-tools").'</a></p>'
        ));
    }

    public function save_settings() {
        if (defined('SMART_PLUGINS_CENTRAL')) {
            $this->admin_page_url = 'admin.php';
        }

        if (isset($_POST['option_page']) && $_POST['option_page'] == 'simple-smtp-tools-import') {
            check_admin_referer('simple-smtp-tools-import-options');

            if (is_uploaded_file($_FILES['import_file']['tmp_name'])) {
                $data = file_get_contents($_FILES['import_file']['tmp_name']);
                $data = maybe_unserialize($data);

                if (is_object($data)) {
                    $import_done = false;

                    $settings = isset($_POST['import_settings']) && isset($data->{'simple-smtp-tools'});

                    if ($settings) {
                        $import_done = true;

                        global $sst_core_loader;

                        $sst_core_loader->settings = $data->{'simple-smtp-tools'};
                        $sst_core_loader->save();
                    }

                    if ($import_done) {
                        wp_redirect($this->admin_page_url.'?page=simple-smtp-tools&tab=impexp&settings-updated=true');
                    } else {
                        wp_redirect($this->admin_page_url.'?page=simple-smtp-tools&tab=impexp&import-nothing=true');
                    }
                    exit;
                }
            }

            wp_redirect($this->admin_page_url.'?page=simple-smtp-tools&tab=impexp&import-failed=true');
            exit;
        }

        if (isset($_POST['option_page']) && $_POST['option_page'] == 'simple-smtp-tools') {
            check_admin_referer('simple-smtp-tools-options');

            global $sst_core_loader;

            $sst_core_loader->set('email_sender_active', isset($_POST['email_sender_active']));
            $sst_core_loader->set('email_sender_email', strip_tags(stripslashes($_POST['email_sender_email'])));
            $sst_core_loader->set('email_sender_name', strip_tags(stripslashes($_POST['email_sender_name'])));
            $sst_core_loader->set('smtp_active', isset($_POST['smtp_active']));
            $sst_core_loader->set('smtp_host', strip_tags(stripslashes($_POST['smtp_host'])));
            $sst_core_loader->set('smtp_port', strip_tags(stripslashes($_POST['smtp_port'])));
            $sst_core_loader->set('smtp_username', strip_tags(stripslashes($_POST['smtp_username'])));
            $sst_core_loader->set('smtp_password', strip_tags(stripslashes($_POST['smtp_password'])));
            $sst_core_loader->set('smtp_encryption', strip_tags(stripslashes($_POST['smtp_encryption'])));
            $sst_core_loader->set('smtp_settings', strip_tags(stripslashes($_POST['smtp_settings'])));

            $sst_core_loader->save();

            wp_redirect($this->admin_page_url.'?page=simple-smtp-tools&settings-updated=true');
            exit;
        }
    }

    public function settings() {
        global $sst_core_loader;

        if (isset($_GET['tab']) && $_GET['tab'] == 'about') {
            $about = $sst_core_loader->settings;
        } else {
            $settings = $sst_core_loader->settings;
        }

        include(SST_PATH.'forms/index.php');
    }
}

$sst_core_admin = new sst_admin();

?>