<?php

/*
Plugin Name: Simple SMTP Tools
Plugin URI: http://www.smartplugins.info/plugin/wordpress/simple-smtp-tools/
Description: Modify send email and from fields for emails and set external SMTP server (with direct support for GMail, Yahoo, Outlook...) to send emails in WordPress.
Version: 2.1
Author: Milan Petrovic
Author URI: http://www.dev4press.com/

== Copyright ==
Copyright 2008 - 2017 Milan Petrovic (email: plugins@millan.rs)
*/

class sst_loader {
    public $settings = array();
    public $servers = array();

    function __construct() {
        global $wp_version;

        define('SST_WP_VERSION', intval(substr(str_replace('.', '', $wp_version), 0, 2)));

        $_dirname = trailingslashit(dirname(__FILE__));
        $_urlname = plugin_dir_url(__FILE__);

        define('SST_PATH', $_dirname);
        define('SST_URL', $_urlname);

        require_once(SST_PATH.'core/defaults.php');

        if (!defined('SST_EOL')) {
            define('SST_EOL', "\r\n");
        }

        if (is_admin()) {
            require_once(SST_PATH.'core/admin.php');
        }

        add_action('plugins_loaded', array(&$this, 'init_translation'));

        add_action('plugins_loaded', array(&$this, 'init_plugin_settings'), 7);
        add_action('plugins_loaded', array(&$this, 'init_email_sender'), 8);
        add_action('plugins_loaded', array(&$this, 'init_smtp_server'), 9);
    }

    public function init_email_sender() {
        if ($this->get('email_sender_active')) {
            add_filter('wp_mail_from', array(&$this, 'wp_mail_from_email'));
            add_filter('wp_mail_from_name', array(&$this, 'wp_mail_from_name'));
        }
    }

    public function init_smtp_server() {
        if ($this->get('smtp_active')) {
            add_action('phpmailer_init', array(&$this, 'phpmailer_init'));
        }
    }

    function phpmailer_init($phpmailer) {
        if (empty($this->servers)) {
            $this->servers = array(
                'gmail' => array('host' => 'smtp.gmail.com', 'port' => '465', 'secure' => 'ssl'),
                'yahoo' => array('host' => 'smtp.mail.yahoo.com', 'port' => '465', 'secure' => 'ssl'),
                'yahoo_plus' => array('host' => 'plus.smtp.mail.yahoo.com', 'port' => '465', 'secure' => 'ssl'),
                'yahoo_uk' => array('host' => 'smtp.mail.yahoo.co.uk', 'port' => '465', 'secure' => 'ssl'),
                'yahoo_de' => array('host' => 'smtp.mail.yahoo.de', 'port' => '465', 'secure' => 'ssl'),
                'yahoo_au' => array('host' => 'smtp.mail.yahoo.com.au', 'port' => '465', 'secure' => 'ssl'),
                'mail' => array('host' => 'smtp.mail.com', 'port' => '465', 'secure' => 'sls'),
                'zoho' => array('host' => 'smtp.zoho.com', 'port' => '465', 'secure' => 'sls'),
                'live' => array('host' => 'smtp.live.com', 'port' => '587', 'secure' => 'tls'),
                'gmx' => array('host' => 'mail.gmx.net', 'port' => '25', 'secure' => ''),
                '1and1' => array('host' => 'smtp.1and1.com', 'port' => '587', 'secure' => 'tls'),
                '1and1_de' => array('host' => 'smtp.1und1.de', 'port' => '587', 'secure' => 'tls'),
                'o2' => array('host' => 'smtp.o2.ie', 'port' => '25', 'secure' => ''),
                'o2_uk' => array('host' => 'smtp.o2.co.uk', 'port' => '25', 'secure' => '')
            );
        }

        $server_setup = $this->get('smtp_settings');

        $phpmailer->IsSMTP();
        $phpmailer->SMTPAuth = false;

        if ($this->get('smtp_password') != '' && $this->get('smtp_username') != '') {
            $phpmailer->SMTPAuth = true;
            $phpmailer->Username = $this->get('smtp_username');
            $phpmailer->Password = $this->get('smtp_password');
        }

        if ($server_setup == 'custom') {
            $phpmailer->Host = $this->get('smtp_host');
            $phpmailer->Port = $this->get('smtp_port') == '' ? 25 : $this->get('smtp_port');
            $phpmailer->SMTPSecure = $this->get('smtp_encryption');
        } else if (isset($this->servers[$server_setup])) {
            $settings = $this->servers[$server_setup];

            $phpmailer->Host = $settings['host'];
            $phpmailer->Port = $settings['port'];
            $phpmailer->SMTPSecure = $settings['secure'];
        }
    }

    function wp_mail_from_email($from_email) {
        if ($this->get('email_sender_email') != '') {
            return $this->get('email_sender_email');
        } else {
            return $from_email;
        }
    }

    function wp_mail_from_name($from_name) {
        if ($this->get('email_sender_name') != '') {
            return $this->get('email_sender_name');
        } else {
            return $from_name;
        }
    }

    public function init_translation() {
        $this->l = get_locale();

        if (!empty($this->l)) {
            load_plugin_textdomain('simple-smtp-tools', false, 'simple-smtp-tools/languages');
        }
    }

    public function init_plugin_settings() {
        $_d = new sst_defaults();

        $this->settings = get_option('simple-smtp-tools');

        if (!is_array($this->settings)) {
            $this->settings = $_d->settings;
            $this->save();
        } else if ($this->settings['__build__'] != $_d->settings['__build__']) {
            $this->settings = $_d->upgrade($this->settings);
            $this->save();
        }

        define('SIMPLE_SMTP_TOOLS', $this->settings['__version__']);
    }

    public function get($name) {
        return $this->settings[$name];
    }

    public function set($name, $value) {
        $this->settings[$name] = $value;
    }

    public function save() {
        update_option('simple-smtp-tools', $this->settings);
    }
}

global $sst_core_loader;
$sst_core_loader = new sst_loader();
