<?php
// Set up the content width value based on the theme's design and stylesheet.
if ( ! isset( $content_width ) ) {
	$content_width = 625;
}
function twentytwelve_setup() {
	load_theme_textdomain( 'twentytwelve' );
	// This theme styles the visual editor with editor-style.css to match the theme style.
	add_editor_style();
	// Load regular editor styles into the new block-based editor.
	add_theme_support( 'editor-styles' );
	// Load default block styles.
	//add_theme_support( 'wp-block-styles' );
	// Add support for responsive embeds.
	add_theme_support( 'responsive-embeds' );
	// Add support for custom color scheme.
	add_theme_support(
		'editor-color-palette',
		array(
			array(
				'name'  => __( 'Blue', 'twentytwelve' ),
				'slug'  => 'blue',
				'color' => '#21759b',
			),
			array(
				'name'  => __( 'Dark Gray', 'twentytwelve' ),
				'slug'  => 'dark-gray',
				'color' => '#444',
			),
			array(
				'name'  => __( 'Medium Gray', 'twentytwelve' ),
				'slug'  => 'medium-gray',
				'color' => '#9f9f9f',
			),
			array(
				'name'  => __( 'Light Gray', 'twentytwelve' ),
				'slug'  => 'light-gray',
				'color' => '#e6e6e6',
			),
			array(
				'name'  => __( 'White', 'twentytwelve' ),
				'slug'  => 'white',
				'color' => '#fff',
			),
		)
	);
	// Adds RSS feed links to <head> for posts and comments.
	add_theme_support( 'automatic-feed-links' );
	// This theme supports a variety of post formats.
	add_theme_support( 'post-formats', array( 'aside', 'image', 'link', 'quote', 'status' ) );
	// This theme uses wp_nav_menu() in one location.
	register_nav_menu( 'primary', __( 'Primary Menu', 'twentytwelve' ) );
	/*
	 * This theme supports custom background color and image,
	 * and here we also set up the default background color.
	 */
	add_theme_support(
		'custom-background',
		array(
			'default-color' => 'e6e6e6',
		)
	);
	// This theme uses a custom image size for featured images, displayed on "standard" posts.
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 624, 9999 ); // Unlimited height, soft crop.
	// Indicate widget sidebars can use selective refresh in the Customizer.
	add_theme_support( 'customize-selective-refresh-widgets' );
}
add_action( 'after_setup_theme', 'twentytwelve_setup' );
/**
 * Add support for a custom header image.
 */
require get_template_directory() . '/inc/custom-header.php';
/**
 * Enqueue scripts and styles for front end.
 *
 * @since Twenty Twelve 1.0
 */
function twentytwelve_scripts_styles() {
	global $wp_styles;
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	// Adds JavaScript for handling the navigation menu hide-and-show behavior.
	//wp_enqueue_script( 'bootstrap-js', get_template_directory_uri() . '/js/bootstrap.min.js', array( 'jquery' ), '20201811', true );
	wp_enqueue_script( 'carousel-js', get_template_directory_uri() . '/js/owl.carousel.js', array( 'jquery' ), '20201811', true );
	wp_enqueue_script( 'custom-js', get_template_directory_uri() . '/js/custom.js', array( 'jquery' ), '20201204', true );
	wp_localize_script( 'custom-js', 'customAjax', array( 'ajaxurl' => admin_url( 'admin-ajax.php' ) ) );
	
	// Loads our main stylesheet.
	wp_enqueue_style( 'theme-style', get_stylesheet_uri(), array(), '20190507' );
	wp_enqueue_style( 'bootstrap-style', get_template_directory_uri() . '/css/bootstrap.css', array( 'theme-style' ), '20201811' );
	wp_enqueue_style( 'carousel-style', get_template_directory_uri() . '/css/owl.carousel.css', array( 'theme-style' ), '20201811' );
	wp_enqueue_style( 'carousel-theme-style', get_template_directory_uri() . '/css/owl.theme.default.css', array( 'theme-style' ), '20201811' );
	wp_enqueue_style( 'custom-style', get_template_directory_uri() . '/css/style.css', array( 'theme-style' ), '20201811' );
}
add_action( 'wp_enqueue_scripts', 'twentytwelve_scripts_styles' );

function twentytwelve_wp_title( $title, $sep ) {
	global $paged, $page;
	if ( is_feed() ) {
		return $title;
	}
	// Add the site name.
	$title .= get_bloginfo( 'name', 'display' );
	// Add the site description for the home/front page.
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) ) {
		$title = "$title $sep $site_description";
	}
	// Add a page number if necessary.
	if ( ( $paged >= 2 || $page >= 2 ) && ! is_404() ) {
		/* translators: %s: Page number. */
		$title = "$title $sep " . sprintf( __( 'Page %s', 'twentytwelve' ), max( $paged, $page ) );
	}
	return $title;
}
add_filter( 'wp_title', 'twentytwelve_wp_title', 10, 2 );
function twentytwelve_page_menu_args( $args ) {
	if ( ! isset( $args['show_home'] ) ) {
		$args['show_home'] = true;
	}
	return $args;
}
add_filter( 'wp_page_menu_args', 'twentytwelve_page_menu_args' );
function twentytwelve_widgets_init() {
	register_sidebar(
		array(
			'name'          => __( 'Main Sidebar', 'twentytwelve' ),
			'id'            => 'sidebar-1',
			'description'   => __( 'Appears on posts and pages except the optional Front Page template, which has its own widgets', 'twentytwelve' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		)
	);
	register_sidebar(
		array(
			'name'          => __( 'First Front Page Widget Area', 'twentytwelve' ),
			'id'            => 'sidebar-2',
			'description'   => __( 'Appears when using the optional Front Page template with a page set as Static Front Page', 'twentytwelve' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		)
	);
	register_sidebar(
		array(
			'name'          => __( 'Second Front Page Widget Area', 'twentytwelve' ),
			'id'            => 'sidebar-3',
			'description'   => __( 'Appears when using the optional Front Page template with a page set as Static Front Page', 'twentytwelve' ),
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		)
	);
}
add_action( 'widgets_init', 'twentytwelve_widgets_init' );
if ( ! function_exists( 'twentytwelve_content_nav' ) ) :
	/**
	 * Displays navigation to next/previous pages when applicable.
	 *
	 * @since Twenty Twelve 1.0
	 */
	function twentytwelve_content_nav( $html_id ) {
		global $wp_query;
		if ( $wp_query->max_num_pages > 1 ) : ?>
			<nav id="<?php echo esc_attr( $html_id ); ?>" class="navigation" role="navigation">
				<h3 class="assistive-text"><?php _e( 'Post navigation', 'twentytwelve' ); ?></h3>
				<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older posts', 'twentytwelve' ) ); ?></div>
				<div class="nav-next"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&rarr;</span>', 'twentytwelve' ) ); ?></div>
			</nav><!-- .navigation -->
			<?php
	endif;
	}
endif;
if ( ! function_exists( 'twentytwelve_comment' ) ) :
	function twentytwelve_comment( $comment, $args, $depth ) {
		$GLOBALS['comment'] = $comment;
		switch ( $comment->comment_type ) :
			case 'pingback':
			case 'trackback':
				// Display trackbacks differently than normal comments.
				?>
		<li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>">
		<p><?php _e( 'Pingback:', 'twentytwelve' ); ?> <?php comment_author_link(); ?> <?php edit_comment_link( __( '(Edit)', 'twentytwelve' ), '<span class="edit-link">', '</span>' ); ?></p>
				<?php
				break;
			default:
				// Proceed with normal comments.
				global $post;
				?>
		<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<article id="comment-<?php comment_ID(); ?>" class="comment">
			<header class="comment-meta comment-author vcard">
				<?php
					echo get_avatar( $comment, 44 );
					printf(
						'<cite><b class="fn">%1$s</b> %2$s</cite>',
						get_comment_author_link(),
						// If current post author is also comment author, make it known visually.
						( $comment->user_id === $post->post_author ) ? '<span>' . __( 'Post author', 'twentytwelve' ) . '</span>' : ''
					);
					printf(
						'<a href="%1$s"><time datetime="%2$s">%3$s</time></a>',
						esc_url( get_comment_link( $comment->comment_ID ) ),
						get_comment_time( 'c' ),
						/* translators: 1: Date, 2: Time. */
						sprintf( __( '%1$s at %2$s', 'twentytwelve' ), get_comment_date(), get_comment_time() )
					);
				?>
				</header><!-- .comment-meta -->
				<?php
				$commenter = wp_get_current_commenter();
				if ( $commenter['comment_author_email'] ) {
					$moderation_note = __( 'Your comment is awaiting moderation.', 'twentytwelve' );
				} else {
					$moderation_note = __( 'Your comment is awaiting moderation. This is a preview, your comment will be visible after it has been approved.', 'twentytwelve' );
				}
				?>
				<?php if ( '0' == $comment->comment_approved ) : ?>
				<p class="comment-awaiting-moderation"><?php echo $moderation_note; ?></p>
				<?php endif; ?>
				<section class="comment-content comment">
				<?php comment_text(); ?>
				<?php edit_comment_link( __( 'Edit', 'twentytwelve' ), '<p class="edit-link">', '</p>' ); ?>
				</section><!-- .comment-content -->
				<div class="reply">
				<?php
				comment_reply_link(
					array_merge(
						$args,
						array(
							'reply_text' => __( 'Reply', 'twentytwelve' ),
							'after'      => ' <span>&darr;</span>',
							'depth'      => $depth,
							'max_depth'  => $args['max_depth'],
						)
					)
				);
				?>
				</div><!-- .reply -->
			</article><!-- #comment-## -->
				<?php
				break;
		endswitch; // End comment_type check.
	}
endif;
if ( ! function_exists( 'twentytwelve_entry_meta' ) ) :
	function twentytwelve_entry_meta() {
		/* translators: Used between list items, there is a space after the comma. */
		$categories_list = get_the_category_list( __( ', ', 'twentytwelve' ) );
		/* translators: Used between list items, there is a space after the comma. */
		$tags_list = get_the_tag_list( '', __( ', ', 'twentytwelve' ) );
		$date = sprintf(
			'<a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date" datetime="%3$s">%4$s</time></a>',
			esc_url( get_permalink() ),
			esc_attr( get_the_time() ),
			esc_attr( get_the_date( 'c' ) ),
			esc_html( get_the_date() )
		);
		$author = sprintf(
			'<span class="author vcard"><a class="url fn n" href="%1$s" title="%2$s" rel="author">%3$s</a></span>',
			esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
			/* translators: %s: Author display name. */
			esc_attr( sprintf( __( 'View all posts by %s', 'twentytwelve' ), get_the_author() ) ),
			get_the_author()
		);
		if ( $tags_list && ! is_wp_error( $tags_list ) ) {
			/* translators: 1: Category name, 2: Tag name, 3: Date, 4: Author display name. */
			$utility_text = __( 'This entry was posted in %1$s and tagged %2$s on %3$s<span class="by-author"> by %4$s</span>.', 'twentytwelve' );
		} elseif ( $categories_list ) {
			/* translators: 1: Category name, 3: Date, 4: Author display name. */
			$utility_text = __( 'This entry was posted in %1$s on %3$s<span class="by-author"> by %4$s</span>.', 'twentytwelve' );
		} else {
			/* translators: 3: Date, 4: Author display name. */
			$utility_text = __( 'This entry was posted on %3$s<span class="by-author"> by %4$s</span>.', 'twentytwelve' );
		}
		printf(
			$utility_text,
			$categories_list,
			$tags_list,
			$date,
			$author
		);
	}
endif;
function twentytwelve_body_class( $classes ) {
	$background_color = get_background_color();
	$background_image = get_background_image();
	if ( ! is_active_sidebar( 'sidebar-1' ) || is_page_template( 'page-templates/full-width.php' ) ) {
		$classes[] = 'full-width';
	}
	if ( is_page_template( 'page-templates/front-page.php' ) ) {
		$classes[] = 'template-front-page';
		if ( has_post_thumbnail() ) {
			$classes[] = 'has-post-thumbnail';
		}
		if ( is_active_sidebar( 'sidebar-2' ) && is_active_sidebar( 'sidebar-3' ) ) {
			$classes[] = 'two-sidebars';
		}
	}
	if ( empty( $background_image ) ) {
		if ( empty( $background_color ) ) {
			$classes[] = 'custom-background-empty';
		} elseif ( in_array( $background_color, array( 'fff', 'ffffff' ), true ) ) {
			$classes[] = 'custom-background-white';
		}
	}
	// Enable custom font class only if the font CSS is queued to load.
	if ( wp_style_is( 'twentytwelve-fonts', 'queue' ) ) {
		$classes[] = 'custom-font-enabled';
	}
	if ( ! is_multi_author() ) {
		$classes[] = 'single-author';
	}
	return $classes;
}
add_filter( 'body_class', 'twentytwelve_body_class' );
function twentytwelve_content_width() {
	if ( is_page_template( 'page-templates/full-width.php' ) || is_attachment() || ! is_active_sidebar( 'sidebar-1' ) ) {
		global $content_width;
		$content_width = 960;
	}
}
add_action( 'template_redirect', 'twentytwelve_content_width' );
function twentytwelve_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial(
			'blogname',
			array(
				'selector'            => '.site-title > a',
				'container_inclusive' => false,
				'render_callback'     => 'twentytwelve_customize_partial_blogname',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'blogdescription',
			array(
				'selector'            => '.site-description',
				'container_inclusive' => false,
				'render_callback'     => 'twentytwelve_customize_partial_blogdescription',
			)
		);
	}
}
add_action( 'customize_register', 'twentytwelve_customize_register' );
function twentytwelve_customize_partial_blogname() {
	bloginfo( 'name' );
}
function twentytwelve_customize_partial_blogdescription() {
	bloginfo( 'description' );
}
function twentytwelve_customize_preview_js() {
	wp_enqueue_script( 'twentytwelve-customizer', get_template_directory_uri() . '/js/theme-customizer.js', array( 'customize-preview' ), '20141120', true );
}
add_action( 'customize_preview_init', 'twentytwelve_customize_preview_js' );
function twentytwelve_widget_tag_cloud_args( $args ) {
	$args['largest']  = 22;
	$args['smallest'] = 8;
	$args['unit']     = 'pt';
	$args['format']   = 'list';
	return $args;
}
add_filter( 'widget_tag_cloud_args', 'twentytwelve_widget_tag_cloud_args' );
if ( ! function_exists( 'wp_body_open' ) ) :
	function wp_body_open() {
		do_action( 'wp_body_open' );
	}
endif;
if( function_exists('acf_add_options_page') ) {
	//acf_add_options_page();
	//acf_add_options_sub_page('Bulk Update');
	$parent = acf_add_options_page(array(
		'page_title' 	=> 'lisäasetukset',
		'menu_title' 	=> 'lisäasetukset',
		'redirect' 		=> false
	));
}

// Remove different fields on user profile page
function hide_personal_options(){
echo "\n" . '<script type="text/javascript">jQuery(document).ready(function($) { $(\'form#your-profile > h3:first\').hide(); $(\'form#your-profile > table:first\').hide(); $(\'form#your-profile\').show(); });</script>' . "\n";
}
add_action('admin_head','hide_personal_options');

add_filter('user_contactmethods', 'remove_contactmethods');
function remove_contactmethods($contactmethods) {
	unset($contactmethods['aim']);
	unset($contactmethods['yim']);
	unset($contactmethods['jabber']);
	unset($contactmethods['website']);
	return $contactmethods;
}
add_action('admin_head', 'profile_admin_buffer_start');
add_action('admin_footer', 'profile_admin_buffer_end');
function remove_plain_bio($buffer){
	$titles = array('#<h2>'.__('About Yourself').'</h2>#','#<h2>'.__('About the user').'</h2>#');
	$buffer=preg_replace($titles,'<h2>'.__('Password').'</h2>',$buffer,1);
	$biotable='#<h2>'.__('Password').'</h2>.+?<table.+?/tr>#s';
	$buffer=preg_replace($biotable,'<h2>'.__('Password').'</h2> <table class="form-table">',$buffer,1);
	return $buffer;
}
function profile_admin_buffer_start() {ob_start('remove_plain_bio');}
function profile_admin_buffer_end() {ob_end_flush();}
function remove_website_row_wpse_94963_css(){
    echo '<style>tr.user-url-wrap{ display: none; }</style>';
	echo '<style>tr.user-nickname-wrap{ display: none; }</style>';
	echo '<style>tr.user-display-name-wrap{ display: none; }</style>';
}
add_action( 'admin_head-user-edit.php', 'remove_website_row_wpse_94963_css' );
add_action( 'admin_head-profile.php',   'remove_website_row_wpse_94963_css' );

add_filter( 'gform_recaptcha_language', 'set_recaptcha_language', 10, 2 );
function set_recaptcha_language( $language, $form_id )
{
    //must be a language code supported by Google reCAPTCHA - https://developers.google.com/recaptcha/docs/language
    return 'fi';
}

// Fully Disable Gutenberg editor.
add_filter('use_block_editor_for_post_type', '__return_false', 10);
// Don’t load Gutenberg-related stylesheets.
add_action( 'wp_enqueue_scripts', 'remove_block_css', 100 );
function remove_block_css() {
	wp_dequeue_style( 'wp-block-library' ); // Wordpress core
	wp_dequeue_style( 'wp-block-library-theme' ); // Wordpress core
	wp_dequeue_style( 'wc-block-style' ); // WooCommerce
	wp_dequeue_style( 'storefront-gutenberg-blocks' ); // Storefront theme
}

// shortcode to display testimonials from backend options page.
function shortcode_testimonial($atts){
	extract(shortcode_atts( array("limit"=>""),$atts ) );
	$testimonials = get_field('testimonials', 'option');
	$res  = '';
	if($testimonials) {
		$res  .= "<div class='testimonials_outer owl-carousel owl-theme'>";
		foreach($testimonials as $testi){
			$res  .= "<div class='testimonial_box'>";
				$res  .= "<div class='testimonial_box_inner'>";
					if($testi['image']){ 
						$res  .= "<div class='testimonial_image'><img src='".$testi['image']."' title='".$testi['title']."'></div>"; 
					}
					$res  .= "<div class='testimonial_description'>".$testi['description']."</div>";
					$res  .= "<div class='testimonial_title'>".$testi['title']."</div>";
				$res .= "</div>";
			$res .= "</div>";
		}
		$res .= "</div>";
	}
	return $res;
};
add_shortcode("testimonials_carousal", "shortcode_testimonial");

// shortcode to display services carsoual
function shortcode_services($atts){

	$services = get_field('services', 'option');
	//echo '<pre>';
	//print_r($result['cards']);
	//echo '</pre>';
	$res  = '';
	if($services) {
		$res  .= "<div class='featured_listing_wraper'>";
			$res .="<h2 class='discover_best_detals'>Palvelumme</h2>";
			$res  .= "<div class='featured_listing_outer owl-carousel owl-theme'>";
			foreach($services as $serv){
				$title = $serv['title'];
				$sub_title = $serv['sub_title'];
				$description = $serv['description'];
				$image = $serv['image'];
				$res  .= "<div class='flist_box'>";
					$res  .= "<div class='flist_box_head'>";
						$res  .= "<div class='flist_box_head_left'>";
							$res  .= "<div class='flist_title'>".$title."</div>";
							$res  .= "<div class='flist_sub_title'>".$sub_title."</div>";
						$res .= "</div>";
						$res  .= "<div class='flist_box_head_right'>";
							if($image){ $res  .= "<img src='".$image."' title='".$title."'>"; }
						$res .= "</div>";
					$res .= "</div>";
					$res  .= "<div class='flist_box_summary'>";
						if($description){ 
							$res  .= "<div class='flist_box_summary_inner'><h3>Kuvaus</h3>".$description."</div>";
						}
						if($serv['link']){
							$res .= "<a href='".get_permalink($serv['link'])."' class='flist_box_btn'>lue lisää <i class='fa-solid fa-chevrons-right'></i></a>";
						}
					$res .= "</div>";
				$res .= "</div>";
			}
			$res .= "</div>";
		$res .= "</div>";
	}
	return $res;
};
add_shortcode("services", "shortcode_services");